Struct PathValidation
Source pub struct PathValidation {
pub path: PathBuf,
pub valid: bool,
pub error: Option<ValidationError>,
}
Result of path validation
Whether the path is valid
Error if validation failed
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.