pub struct PermissionModel { /* private fields */ }Expand description
Permission model for validating operations
Implementations
Sourceimpl PermissionModel
impl PermissionModel
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new permission model with permissive default settings Allows all operations unless explicitly restricted by sandbox
Sourcepub fn with_sandbox(self, root: PathBuf) -> Self
pub fn with_sandbox(self, root: PathBuf) -> Self
Enable sandbox mode with a root directory
Sourcepub fn allow_read(self, path: PathBuf) -> Self
pub fn allow_read(self, path: PathBuf) -> Self
Add allowed read path
Sourcepub fn allow_write(self, path: PathBuf) -> Self
pub fn allow_write(self, path: PathBuf) -> Self
Add allowed write path
Sourcepub fn check_permission(
&self,
path: &Path,
permission: Permission,
) -> Result<()>
pub fn check_permission( &self, path: &Path, permission: Permission, ) -> Result<()>
Check if a path is allowed for the given permission
Sourcepub fn is_env_var_restricted(&self, var: &str) -> bool
pub fn is_env_var_restricted(&self, var: &str) -> bool
Check if environment variable is restricted